"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = exports.logger = exports.SqlDatabaseNodeOptions = void 0;
const transport_1 = require("../../../transport");
exports.SqlDatabaseNodeOptions = {};
let _logger = null;
const logger = () => _logger;
exports.logger = logger;
async function execute() {
    _logger = this.logger;
    const { user, password, jdbcUrl, driverDirectory, maxConcurrentConnections } = await this.getCredentials('sqlDatabase');
    exports.SqlDatabaseNodeOptions.continueOnFail = this.continueOnFail();
    const javaOptions = {
        driverDirectory
    };
    const connectionOptions = {
        user,
        password,
        jdbcUrl
    };
    if (typeof maxConcurrentConnections !== 'number') {
        const _maxConcurrentConnections = parseInt(maxConcurrentConnections);
        if (!isNaN(_maxConcurrentConnections)) {
            connectionOptions.maxConcurrentConnections = _maxConcurrentConnections;
        }
        else {
            if (!exports.SqlDatabaseNodeOptions.continueOnFail) {
                throw new Error("Invalid parameter supplied: maxConcurrentConnections");
            }
            connectionOptions.maxConcurrentConnections = 1;
        }
    }
    else {
        connectionOptions.maxConcurrentConnections = maxConcurrentConnections;
    }
    const outputOptions = this.getNodeParameter('additionalOptions', 0);
    const numberOfStatements = this.getInputData().length;
    const getStatement = (i) => {
        if (i < numberOfStatements) {
            return this.getNodeParameter('sqlStatement', i);
        }
        return null;
    };
    const batchResults = await (0, transport_1.executeStatementBatch)(javaOptions, connectionOptions, getStatement);
    return formatForOutput(batchResults, outputOptions);
}
exports.execute = execute;
const formatForOutput = (batchResults, { groupOutput }) => {
    const results = [];
    (0, exports.logger)().log('debug', `Formatting result for output`);
    let referenceCols = null;
    for (let i = 0; i < batchResults.length; i++) {
        const { columns, data, itemIndex } = batchResults[i];
        const resultTarget = groupOutput ? results : [];
        if (groupOutput) {
            const cols = columns.map(column => column.name).join('|');
            if (i === 0) {
                referenceCols = columns.map(column => column.name).join('|');
            }
            if (cols !== referenceCols) {
                throw new Error(`Unable to group output - column mismatch between query results\n\tExpected: ${referenceCols}\n\tGot: ${cols}`);
            }
        }
        for (let i = 0; i < data.length; i++) {
            const formattedRow = {};
            for (let j = 0; j < columns.length; j++) {
                formattedRow[columns[j].name] = data[i][j];
            }
            if (groupOutput) {
                resultTarget.push({ json: formattedRow, pairedItem: itemIndex });
            }
            else {
                resultTarget.push(formattedRow);
            }
        }
        if (!groupOutput) {
            results.push({ json: { result: resultTarget }, pairedItem: itemIndex });
        }
    }
    return results;
};
//# sourceMappingURL=execute.js.map