"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.executeStatementBatch = void 0;
const java = __importStar(require("./java"));
const worker_1 = require("./worker");
const statement_1 = require("./statement");
const execute_1 = require("../actions/statement/execute/execute");
const sleep = (ms) => new Promise((r) => setTimeout(r, ms));
const executeStatementBatch = async (javaOptions, connectionOptions, getStatement) => {
    const javaInstance = java.initializeJvm(javaOptions);
    javaInstance.import('java.sql.Types');
    const { dispatchTask, busyWorkerCount, destroyWorkerPool } = (0, worker_1.createWorkerPool)(connectionOptions);
    const { dequeueStatement } = (0, statement_1.createStatementQueue)(getStatement);
    const statementBatchResults = [];
    const taskResults = [];
    (0, execute_1.logger)().log('debug', "Beginning execute statement batch process");
    do {
        const statement = dequeueStatement();
        if (statement.sql === null) {
            const busyWorkers = busyWorkerCount();
            if (busyWorkers > 0) {
                (0, execute_1.logger)().log('debug', `Waiting for ${busyWorkers} worker to finish their task`);
                await sleep(100);
                continue;
            }
            (0, execute_1.logger)().log('debug', "Finished processing all statements");
            break;
        }
        (0, execute_1.logger)().log('debug', `Got item ${statement.itemIndex} from queue, dispatching for processing`);
        let taskResult = null;
        do {
            taskResult = dispatchTask(statement);
            if (taskResult === null) {
                (0, execute_1.logger)().log('debug', "Waiting for free connection to continue processing");
                await sleep(1000);
            }
        } while (taskResult === null);
        taskResults.push(taskResult);
        taskResult.then(rawResult => {
            (0, execute_1.logger)().log('debug', `Storing result for item ${rawResult.itemIndex}`);
            statementBatchResults.push(rawResult);
        });
    } while (true);
    (0, execute_1.logger)().log('debug', "Closing batch");
    destroyWorkerPool();
    return statementBatchResults;
};
exports.executeStatementBatch = executeStatementBatch;
//# sourceMappingURL=index.js.map