"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeJvm = exports.getJavaInstance = void 0;
const java_1 = __importDefault(require("java"));
const node_fs_1 = require("node:fs");
const execute_1 = require("../actions/statement/execute/execute");
java_1.default.asyncOptions = {
    asyncSuffix: "Async",
    syncSuffix: ""
};
const getJavaInstance = () => {
    return java_1.default;
};
exports.getJavaInstance = getJavaInstance;
const initializeJvm = (javaOptions) => {
    const { driverDirectory } = javaOptions;
    if (java_1.default.isJvmCreated()) {
        return java_1.default;
    }
    try {
        if (driverDirectory) {
            const foundJarFiles = searchDirectoryForFileType(driverDirectory, '.jar');
            if (foundJarFiles.length > 0) {
                for (let pathIndex = 0; pathIndex < foundJarFiles.length; pathIndex++) {
                    java_1.default.classpath.push(foundJarFiles[pathIndex]);
                }
            }
        }
    }
    catch (e) {
        const err = [];
        err.push("Unable to walk driver directory");
        if (e.cause = "PATH_NOT_FOUND") {
            err.push("Specified path not found");
        }
        (0, execute_1.logger)().log('error', err.join(': '));
        throw Error(err.join(': '));
    }
    return java_1.default;
};
exports.initializeJvm = initializeJvm;
const searchDirectoryForFileType = (directory, fileExtension) => {
    const matchedFiles = [];
    if (!(0, node_fs_1.realpathSync)(directory)) {
        throw Error("Specified path does not exist", { cause: 'PATH_NOT_FOUND' });
    }
    const dir = (0, node_fs_1.readdirSync)(directory, {
        withFileTypes: true,
        recursive: true
    });
    for (const dirEnt of dir) {
        if (dirEnt?.name?.endsWith(fileExtension)) {
            matchedFiles.push(`${dirEnt.path}/${dirEnt.name}`);
        }
    }
    return matchedFiles;
};
//# sourceMappingURL=java.js.map