"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.release = exports.reserve = exports.createConnectionPool = void 0;
const java_1 = require("./java");
const uuid_1 = require("uuid");
const createConnectionPool = (user, password, jdbcUrl, minimumPoolConnections, maximumPoolConnections) => {
    const pool = [];
    const reservePoolConnection = () => {
        if (pool.length >= maximumPoolConnections) {
            return false;
        }
        const connectionObject = (0, exports.reserve)(user, password, jdbcUrl);
        pool.push(connectionObject);
        return connectionObject;
    };
    const releasePoolConnection = (uuid) => {
        if (pool.length <= minimumPoolConnections) {
            return false;
        }
        (0, exports.release)(pool[uuid]);
        return true;
    };
    const destroyConnectionPool = () => {
        const connectionUuids = Object.keys(pool);
        for (let i = 0; i < connectionUuids.length; i++) {
            const uuid = connectionUuids[i];
            (0, exports.release)(pool[uuid]);
        }
        return true;
    };
    for (let p = 0; p < minimumPoolConnections; p++) {
        reservePoolConnection();
    }
    return {
        reservePoolConnection,
        releasePoolConnection,
        destroyConnectionPool,
        getConnectionPool: () => [...pool],
        getConnectionCount: () => pool.length
    };
};
exports.createConnectionPool = createConnectionPool;
const reserve = (user, password, jdbcUrl) => {
    const java = (0, java_1.getJavaInstance)();
    const connectionProperties = java.newInstanceSync('java.util.Properties');
    if (user) {
        connectionProperties.put('user', user);
    }
    if (password) {
        connectionProperties.put('password', password);
    }
    const connectionObject = java.callStaticMethodSync('java.sql.DriverManager', 'getConnection', jdbcUrl, connectionProperties);
    connectionObject.uuid = (0, uuid_1.v4)();
    return connectionObject;
};
exports.reserve = reserve;
const release = (connectionObject) => {
    return connectionObject.close();
};
exports.release = release;
//# sourceMappingURL=pool.js.map