"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processResultSet = void 0;
const execute_1 = require("../actions/statement/execute/execute");
const sqltypes_1 = require("./sqltypes");
const processResultSet = async (resultSetObject) => {
    try {
        (0, execute_1.logger)().log('debug', `Grabbing metadata`);
        const resultSetMetaDataObject = resultSetObject.getMetaData();
        const columnCount = resultSetMetaDataObject.getColumnCount();
        const columns = [];
        (0, execute_1.logger)().log('debug', `Detecting columns`);
        for (let i = 1; i <= columnCount; i++) {
            columns.push({
                name: resultSetMetaDataObject.getColumnName(i),
                index: i,
                label: resultSetMetaDataObject.getColumnLabel(i),
                type: {
                    id: resultSetMetaDataObject.getColumnType(i),
                    name: (0, sqltypes_1.getColumnTypeByValue)(resultSetMetaDataObject.getColumnType(i))
                },
            });
        }
        (0, execute_1.logger)().log('debug', `Retrieving data`);
        const data = [];
        while (resultSetObject.next()) {
            const row = [];
            for (let i = 0, n = columns.length; i < n; i++) {
                const data = resultSetObject['get' + columns[i].type.name](columns[i].index);
                if (data === null) {
                    row.push(null);
                }
                else {
                    row.push(data.toString());
                }
            }
            data.push(row);
        }
        (0, execute_1.logger)().log('debug', `Returning data`);
        return { columns, data };
    }
    catch (e) {
        (0, execute_1.logger)().log('error', `Error while processing resultset\n\t${e}`);
        throw e;
    }
};
exports.processResultSet = processResultSet;
//# sourceMappingURL=resultset.js.map