"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processStatement = exports.createStatementQueue = void 0;
const execute_1 = require("../actions/statement/execute/execute");
const resultset_1 = require("./resultset");
const createStatementQueue = (getStatement) => {
    const retryQueue = [];
    let itemIndex = 0;
    const dequeueStatement = () => {
        if (retryQueue.length > 0) {
            const statement = retryQueue.pop();
            (0, execute_1.logger)().log('debug', `Retrying failed query: ${statement.split('\n').join('\n\t')}`);
            return retryQueue.pop();
        }
        const statement = {
            sql: getStatement(itemIndex),
            itemIndex
        };
        itemIndex++;
        return statement;
    };
    const requeueStatement = (statement) => {
        retryQueue.push(statement);
    };
    return {
        dequeueStatement,
        requeueStatement
    };
};
exports.createStatementQueue = createStatementQueue;
const processStatement = (statement, connectionObject) => {
    return new Promise((resolve, reject) => {
        const { sql, itemIndex } = statement;
        (0, execute_1.logger)().log('debug', `Processing statement at item index ${itemIndex}\n\tsql:\n\t\t${sql.split('\n').join('\t\t\n')}\n`);
        try {
            const statementObject = connectionObject.createStatement();
            statementObject.executeQueryAsync(sql, async (err, resultSetObject) => {
                if (err) {
                    try {
                        if (!statementObject.isClosed()) {
                            statementObject.close();
                        }
                    }
                    catch (e) {
                        (0, execute_1.logger)().log('debug', `Attempted to close statement, but encountered an error\n\titem: ${statement.statementIndex}`);
                    }
                    reject(err);
                    return;
                }
                (0, execute_1.logger)().log('debug', `Executed query, processing resultset`);
                const { columns, data } = await (0, resultset_1.processResultSet)(resultSetObject);
                try {
                    if (!resultSetObject.isClosed()) {
                        resultSetObject.close();
                    }
                }
                catch (e) {
                    (0, execute_1.logger)().log('debug', `Attempted to close resultset, but encountered an error\n\titem: ${statement.statementIndex}`);
                }
                try {
                    if (!statementObject.isClosed()) {
                        statementObject.close();
                    }
                }
                catch (e) {
                    (0, execute_1.logger)().log('debug', `Attempted to close statement, but encountered an error\n\titem: ${statement.statementIndex}`);
                }
                resolve({ columns, data, itemIndex });
                return;
            });
        }
        catch (e) {
            (0, execute_1.logger)().log('error', `Error while processing statement at item index ${statement.itemIndex}`);
            reject(e);
            return;
        }
    });
};
exports.processStatement = processStatement;
//# sourceMappingURL=statement.js.map