"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWorkerPool = void 0;
const java_1 = require("./java");
const uuid_1 = require("uuid");
const statement_1 = require("./statement");
const execute_1 = require("../actions/statement/execute/execute");
const createWorkerPool = (connectionOptions) => {
    const workerPool = [];
    let workerCount = 0;
    const spawnWorker = () => {
        const uuid = (0, uuid_1.v4)();
        const connectionObject = reserveConnection(connectionOptions);
        workerCount++;
        return {
            uuid,
            connectionObject,
            handleTask: (statement) => (0, statement_1.processStatement)(statement, connectionObject)
        };
    };
    return {
        dispatchTask: (statement) => {
            let worker;
            if (workerPool.length === 0) {
                if (workerCount === connectionOptions.maxConcurrentConnections) {
                    return null;
                }
                worker = spawnWorker();
            }
            else {
                worker = workerPool.pop();
            }
            (0, execute_1.logger)().log('debug', `Retrieved worker ${worker.uuid} from free pool`);
            const processPromise = worker.handleTask(statement);
            processPromise.then(() => {
                (0, execute_1.logger)().log('debug', `Returning worker ${worker.uuid} to free pool`);
                workerPool.push(worker);
            });
            return processPromise;
        },
        busyWorkerCount: () => workerCount - workerPool.length,
        destroyWorkerPool: () => {
            while (workerPool.length > 0) {
                const worker = workerPool.pop();
                worker.connectionObject.close();
            }
            (0, execute_1.logger)().log('debug', "Laid off all workers");
        }
    };
};
exports.createWorkerPool = createWorkerPool;
const reserveConnection = (connectionOptions) => {
    const java = (0, java_1.getJavaInstance)();
    const connectionProperties = java.newInstanceSync('java.util.Properties');
    if (connectionOptions.user) {
        connectionProperties.put('user', connectionOptions.user);
    }
    if (connectionOptions.password) {
        connectionProperties.put('password', connectionOptions.password);
    }
    const connectionObject = java.callStaticMethodSync('java.sql.DriverManager', 'getConnection', connectionOptions.jdbcUrl, connectionProperties);
    return connectionObject;
};
//# sourceMappingURL=worker.js.map